==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/bedget/vo/MaterialanalysisVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordmaterialanalysisVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.MaterialanalysisdetailVO;

/**
 * 施工图预算材料分析
 * 
 * @author generator
 * 
 */
public class MaterialanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称

    private java.lang.String createTimeShow; // 创建时间文本显示
    
    private List<MaterialanalysisdetailVO> materialanalysisdetailEntities = new ArrayList<>(); // 施工图预算材料分析子表
    private List<RecordmaterialanalysisVO> recordmaterialanalysisVOS = new ArrayList<>(); // 施工图预算材料分析子表

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    
     /**
      * 施工图预算材料分析子表
      */
     public List<MaterialanalysisdetailVO> getMaterialanalysisdetailEntities() {
        return materialanalysisdetailEntities;
     }

     /**
      * 施工图预算材料分析子表
      */
     public void setMaterialanalysisdetailEntities(List<MaterialanalysisdetailVO> materialanalysisdetailEntities) {
        this.materialanalysisdetailEntities = materialanalysisdetailEntities;
     }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public List<RecordmaterialanalysisVO> getRecordmaterialanalysisVOS() {
        return recordmaterialanalysisVOS;
    }

    public void setRecordmaterialanalysisVOS(List<RecordmaterialanalysisVO> recordmaterialanalysisVOS) {
        this.recordmaterialanalysisVOS = recordmaterialanalysisVOS;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220404.033202-49-sources.jar: com/ejianc/business/bedget/vo/MaterialanalysisVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordmaterialanalysisVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.MaterialanalysisdetailVO;

/**
 * 施工图预算材料分析
 * 
 * @author generator
 * 
 */
public class MaterialanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.lang.String total; // 合计汇总数量
    private java.lang.String createTimeShow; // 创建时间文本显示
    
    private List<MaterialanalysisdetailVO> materialanalysisdetailEntities = new ArrayList<>(); // 施工图预算材料分析子表
    private List<RecordmaterialanalysisVO> recordmaterialanalysisVOS = new ArrayList<>(); // 施工图预算材料分析子表

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    
     /**
      * 施工图预算材料分析子表
      */
     public List<MaterialanalysisdetailVO> getMaterialanalysisdetailEntities() {
        return materialanalysisdetailEntities;
     }

     /**
      * 施工图预算材料分析子表
      */
     public void setMaterialanalysisdetailEntities(List<MaterialanalysisdetailVO> materialanalysisdetailEntities) {
        this.materialanalysisdetailEntities = materialanalysisdetailEntities;
     }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public List<RecordmaterialanalysisVO> getRecordmaterialanalysisVOS() {
        return recordmaterialanalysisVOS;
    }

    public void setRecordmaterialanalysisVOS(List<RecordmaterialanalysisVO> recordmaterialanalysisVOS) {
        this.recordmaterialanalysisVOS = recordmaterialanalysisVOS;
    }

    public String getTotal() {
        return total;
    }

    public void setTotal(String total) {
        this.total = total;
    }
}
